@@ -3,21 +3,20 @@
 
 """Efficiency methods for training.
 
-Examples include :class:`~composer.algorithms.label_smoothing.LabelSmoothing`
-and adding :class:`~composer.algorithms.squeeze_excite.SqueezeExcite` blocks,
+Examples include :class:`.LabelSmoothing` and adding :class:`.SqueezeExcite` blocks,
 among many others.
 
 Algorithms are implemented in both a standalone functional form (see :mod:`composer.functional`)
 and as subclasses of :class:`Algorithm` for integration in the Composer :class:`Trainer`.
 The former are easier to integrate piecemeal into an existing codebase.
 The latter are easier to compose together, since they all have the same public interface
-and work automatically with the Composer :py:class:`~composer.trainer.Trainer`.
+and work automatically with the Composer :py:class:`.Trainer`.
 
 For ease of composability, algorithms in our Trainer are based on the two-way callbacks concept from
 `Howard et al, 2020 <https://arxiv.org/abs/2002.04688>`_. Each algorithm implements two methods:
 
 * :meth:`Algorithm.match`: returns ``True`` if the algorithm should be run given the current
-  :class:`State` and :class:`~composer.core.event.Event`.
+  :class:`State` and :class:`.Event`.
 * :meth:`Algorithm.apply`: performs an in-place modification of the given
   :class:`State`
 
@@ -35,7 +34,7 @@ For example, a simple algorithm that shortens training:
         def apply(self, state: State, event: Event, logger: Logger):
             state.max_duration /= 2  # cut training time in half
 
-For more information about events, see :class:`~composer.core.event.Event`.
+For more information about events, see :class:`.Event`.
 """
 
 from composer.algorithms.alibi import Alibi
