@@ -70,7 +70,7 @@ class GhostBatchNorm(Algorithm):
     running batch normalization on each chunk separately. ``dim=0`` is assumed to
     be the sample axis.
 
-    Runs on :attr:`~composer.core.event.Event.INIT`.
+    Runs on :attr:`.Event.INIT`.
 
     Args:
         ghost_batch_size (int, optional): size of sub-batches to normalize over. Default: ``32``.
