@@ -26,7 +26,7 @@ def _assert_valid_duration(time: Time):
 
 
 class SWA(Algorithm):
-    """Apply Stochastic Weight Averaging (`Izmailov et al, 2018 <https://arxiv.org/abs/1803.05407>`_)
+    """Applies Stochastic Weight Averaging (`Izmailov et al, 2018 <https://arxiv.org/abs/1803.05407>`_).
 
     Stochastic Weight Averaging (SWA) averages model weights sampled at
     different times near the end of training. This leads to better
@@ -44,8 +44,8 @@ class SWA(Algorithm):
        cause slow training if the model weights are large.
 
     Uses PyTorch's `torch.optim.swa_util
-    <https://pytorch.org/docs/stable/optim.html#stochastic-weight-averaging>`_ under the
-    hood.
+    <https://pytorch.org/docs/stable/optim.html#stochastic-weight-averaging>`_
+    under the hood.
 
     See the :doc:`Method Card </method_cards/swa>` for more details.
 
@@ -71,7 +71,7 @@ class SWA(Algorithm):
     Args:
         swa_start (str, optional): The time string denoting the amount of training
             completed before stochastic weight averaging begins. Currently only units of
-            duration ('dur') and epoch ('ep') are supported. Defalt = ``'0.7dur'``.
+            duration ('dur') and epoch ('ep') are supported. Default: ``'0.7dur'``.
         swa_end (str, optional): The time string denoting the amount of training
             completed before the baseline (non-averaged) model is replaced with the
             stochastic weight averaged model. It's important to have at least one epoch
@@ -82,19 +82,19 @@ class SWA(Algorithm):
             the SWA model will not have its buffers updated, which can negatively impact
             accuracy, so ensure ``swa_end`` < :math:`\\frac{N_{epochs}-1}{N_{epochs}}`.
             Currently only units of duration ('dur') and epoch ('ep') are supported.
-            Default = ``'0.97dur'``.
+            Default: ``'0.97dur'``.
         update_interval (str, optional): Time string denoting how often the averaged
             model is updated. For example, ``'1ep'`` means the averaged model will be
-            updated once per epoch, and ``'5ba'`` means the averaged model will be updated
+            updated once per epoch and ``'5ba'`` means the averaged model will be updated
             every 5 batches. Note that for single-epoch training runs (e.g. many NLP
-            training runs) ``update_interval`` must be specified in units of ``'ba'``,
+            training runs), ``update_interval`` must be specified in units of ``'ba'``,
             otherwise SWA won't happen. Also note that very small update intervals (e.g.
-            ``"1ba"``) can substantially slow down training. Default = ``'1ep'``.
+            ``"1ba"``) can substantially slow down training. Default: ``'1ep'``.
         schedule_swa_lr (bool, optional): Flag to determine whether to apply an
-            SWA-specific LR schedule during the period in which SWA is active. Default =
+            SWA-specific LR schedule during the period in which SWA is active. Default:
             ``False``.
         anneal_strategy (str, optional): SWA learning rate annealing schedule strategy.
-            "linear" for linear annealing, "cos" for cosine annealing. Default =
+            ``"linear"`` for linear annealing, ``"cos"`` for cosine annealing. Default:
             ``"linear"``.
         anneal_steps (int, optional): Number of SWA model updates over which to
             anneal SWA learning rate. Note that updates are determined by the
@@ -102,17 +102,17 @@ class SWA(Algorithm):
             ``update_interval = '1ep'``, then the SWA LR will be annealed once per epoch
             for 10 epochs; if ``anneal_steps = 20`` and ``update_interval = '8ba'``, then
             the SWA LR will be annealed once every 8 batches over the course of 160
-            batches (20 steps * 8 batches/step). Default = ``10``.
+            batches (20 steps * 8 batches/step). Default: ``10``.
         swa_lr (float, optional): The final learning rate to anneal towards with the SWA
-            LR scheduler. Set to ``None`` for no annealing. Default = ``None``.
+            LR scheduler. Set to ``None`` for no annealing. Default: ``None``.
     """
 
     def __init__(self,
-                 swa_start: str = "0.7dur",
-                 swa_end: str = "0.97dur",
-                 update_interval: str = "1ep",
+                 swa_start: str = '0.7dur',
+                 swa_end: str = '0.97dur',
+                 update_interval: str = '1ep',
                  schedule_swa_lr: bool = False,
-                 anneal_strategy: str = "linear",
+                 anneal_strategy: str = 'linear',
                  anneal_steps: int = 10,
                  swa_lr: Optional[float] = None):
         self.schedule_swa_lr = schedule_swa_lr
@@ -131,13 +131,13 @@ class SWA(Algorithm):
         self._validate_time()
 
         if anneal_steps <= 0:
-            raise ValueError("anneal_steps must be greater than 0")
+            raise ValueError('anneal_steps must be greater than 0')
 
         # Check annealing_strategy string
-        if self.anneal_strategy.lower() in ["linear", "lin"]:
-            self.anneal_strategy = "linear"
-        elif self.anneal_strategy.lower() in ["cos", "cosine"]:
-            self.anneal_strategy = "cos"
+        if self.anneal_strategy.lower() in ['linear', 'lin']:
+            self.anneal_strategy = 'linear'
+        elif self.anneal_strategy.lower() in ['cos', 'cosine']:
+            self.anneal_strategy = 'cos'
         else:
             raise ValueError("anneal_strategy must be one of {'linear', 'cos'}.")
 
@@ -167,8 +167,8 @@ class SWA(Algorithm):
             raise ValueError('swa_end must be > swa_start.')
         if self.swa_end.unit == TimeUnit.DURATION and self.swa_end == 1:
             log.warning("'swa_end' = '1dur'. Batch norm statistics of averaged model "
-                        "will not be updated. This will negatively impact accuracy. "
-                        "See the documentation for the `swa_end` parameter for details.")
+                        'will not be updated. This will negatively impact accuracy. '
+                        'See the documentation for the `swa_end` parameter for details.')
 
         _assert_valid_duration(self.swa_start)
         _assert_valid_duration(self.swa_end)
@@ -181,7 +181,7 @@ class SWA(Algorithm):
             return state.timestamp.epoch
         elif unit == TimeUnit.DURATION:
             time_elapsed = state.get_elapsed_duration()
-            assert time_elapsed is not None, "Time should have been set on BATCH_END or EPOCH_END."
+            assert time_elapsed is not None, 'Time should have been set on BATCH_END or EPOCH_END.'
             return time_elapsed
         else:
             raise ValueError('units must be in epoch or duration.')
@@ -191,11 +191,11 @@ class SWA(Algorithm):
         if len(schedulers) == 0:
             return 1.0
         if len(schedulers) != 1:
-            raise RuntimeError(f"SWA supports only one scheduler, got {len(schedulers)}")
+            raise RuntimeError(f'SWA supports only one scheduler, got {len(schedulers)}')
         scheduler = schedulers[0]
         last_lr = scheduler.get_last_lr()
         if len(last_lr) != 1:
-            raise RuntimeError(f"SWA supports only one LR; instead found {len(last_lr)}")
+            raise RuntimeError(f'SWA supports only one LR; instead found {len(last_lr)}')
         return last_lr[0]
 
     def match(self, event: Event, state: State) -> bool:
@@ -213,7 +213,7 @@ class SWA(Algorithm):
             self.swa_lr = self._get_last_lr(state.schedulers)
 
             if len(state.optimizers) != 1:
-                raise RuntimeError("SWA supports only one optimizer")
+                raise RuntimeError('SWA supports only one optimizer')
 
             self.swa_scheduler = SWALR(
                 state.optimizers[0],
@@ -253,10 +253,10 @@ class SWA(Algorithm):
             self.swa_completed = True
 
             if state.get_elapsed_duration() == 1:
-                log.warning(("The baseline model was replaced with the SWA model after the end of "
-                             "training. This means that SWA model will not have its batch norm "
-                             "statistics updated. This will negatively impact accuracy. See the "
-                             "documentation for the `swa_end` parameter for details."))
+                log.warning(('The baseline model was replaced with the SWA model after the end of '
+                             'training. This means that SWA model will not have its batch norm '
+                             'statistics updated. This will negatively impact accuracy. See the '
+                             'documentation for the `swa_end` parameter for details.'))
 
             state.model.load_state_dict(self.swa_model.module.state_dict())  # type: ignore
             log.info('Set model to the averaged model')
