@@ -39,25 +39,22 @@ class SpeedMonitor(Callback):
             ...     callbacks=[SpeedMonitor(window_size=100)],
             ... )
 
-    The training throughput is logged by the :class:`~composer.loggers.logger.Logger` to the following keys as
+    The training throughput is logged by the :class:`.Logger` to the following keys as
     described below.
 
-    +-----------------------+-------------------------------------------------------------+
-    | Key                   | Logged data                                                 |
-    +=======================+=============================================================+
-    |                       | Rolling average (over ``window_size`` most recent           |
-    | ``samples/step``      | batches) of the number of samples processed per second      |
-    |                       |                                                             |
-    +-----------------------+-------------------------------------------------------------+
-    |                       | Number of samples processed per second (averaged over       |
-    | ``samples/epoch``     | an entire epoch)                                            |
-    +-----------------------+-------------------------------------------------------------+
-    | ``wall_clock/train``  | Total elapsed training time                                 |
-    +-----------------------+-------------------------------------------------------------+
-    | ``wall_clock/val``    | Total elapsed validation time                               |
-    +-----------------------+-------------------------------------------------------------+
-    | ``wall_clock/total``  | Total elapsed time (wall_clock/train + wall_clock/val)      |
-    +-----------------------+-------------------------------------------------------------+
+    +----------------------------------+-------------------------------------------------------------+
+    | Key                              | Logged data                                                 |
+    +==================================+=============================================================+
+    |                                  | Rolling average (over ``window_size`` most recent           |
+    | ``throughput/samples_per_sec``   | batches) of the number of samples processed per second      |
+    |                                  |                                                             |
+    +----------------------------------+-------------------------------------------------------------+
+    | ``wall_clock/train``             | Total elapsed training time                                 |
+    +----------------------------------+-------------------------------------------------------------+
+    | ``wall_clock/val``               | Total elapsed validation time                               |
+    +----------------------------------+-------------------------------------------------------------+
+    | ``wall_clock/total``             | Total elapsed time (wall_clock/train + wall_clock/val)      |
+    +----------------------------------+-------------------------------------------------------------+
 
     Args:
         window_size (int, optional): Number of batches to use for a rolling average of throughput.
@@ -65,10 +62,6 @@ class SpeedMonitor(Callback):
     """
 
     def __init__(self, window_size: int = 100):
-        # Track the epoch num samples and wct to compute throughput over the entire epoch
-        self.epoch_start_num_samples = 0
-        self.epoch_start_wct = 0.0
-
         # Track the batch num samples and wct to compute throughput over a window of batches
         self.batch_start_num_samples = 0
         self.batch_start_wct = 0.0
@@ -81,8 +74,6 @@ class SpeedMonitor(Callback):
 
     def state_dict(self) -> Dict[str, Any]:
         return {
-            'epoch_start_num_samples': self.epoch_start_num_samples,
-            'epoch_start_wct': self.epoch_start_wct,
             'batch_start_num_samples': self.batch_start_num_samples,
             'batch_start_wct': self.batch_start_wct,
             'batch_wct_buffer': self.batch_wct_buffer,
@@ -93,8 +84,6 @@ class SpeedMonitor(Callback):
         }
 
     def load_state_dict(self, state: Dict[str, Any]) -> None:
-        self.epoch_start_num_samples = state['epoch_start_num_samples']
-        self.epoch_start_wct = state['epoch_start_wct']
         self.batch_start_num_samples = state['batch_start_num_samples']
         self.batch_start_wct = state['batch_start_wct']
         self.batch_wct_buffer = deque(
@@ -107,11 +96,6 @@ class SpeedMonitor(Callback):
         )
         self.total_eval_wct = state['total_eval_wct']
 
-    def epoch_start(self, state: State, logger: Logger):
-        del logger  # unused
-        self.epoch_start_wct = state.timestamp.total_wct.total_seconds()
-        self.epoch_start_num_samples = int(state.timestamp.sample)
-
     def batch_start(self, state: State, logger: Logger) -> None:
         del logger  # unused
         self.batch_start_wct = state.timestamp.total_wct.total_seconds()
@@ -128,7 +112,7 @@ class SpeedMonitor(Callback):
         # Log the throughput
         if len(self.batch_num_samples_buffer) == self.window_size:
             throughput = sum(self.batch_num_samples_buffer) / sum(self.batch_wct_buffer)
-            logger.data_batch({'samples/step': throughput})
+            logger.data_batch({'throughput/samples_per_sec': throughput})
 
         # Log the time
         # `state.timestamp` excludes any time spent in evaluation
@@ -141,12 +125,3 @@ class SpeedMonitor(Callback):
     def eval_end(self, state: State, logger: Logger):
         del logger  # unused
         self.total_eval_wct += state.eval_timestamp.total_wct.total_seconds()
-
-    def epoch_end(self, state: State, logger: Logger):
-        # `state.timestamp` excludes any time spent in evaluation
-        epoch_time_in_train = state.timestamp.total_wct.total_seconds() - self.epoch_start_wct
-        train_examples_per_epoch = int(state.timestamp.sample) - self.epoch_start_num_samples
-
-        logger.data_epoch({
-            'samples/epoch': train_examples_per_epoch / epoch_time_in_train,
-        })
