@@ -10,6 +10,7 @@ import warnings
 from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional, Sequence, Union, cast
 
 import torch
+import torch.nn
 import torch.nn.modules.utils
 from torch.nn.parallel import DistributedDataParallel
 from torch.optim import Optimizer
@@ -17,7 +18,7 @@ from torch.optim import Optimizer
 from composer.core.precision import Precision
 from composer.core.serializable import Serializable
 from composer.core.time import Time, Timestamp, TimeUnit
-from composer.utils import batch_get, batch_set, dist, ensure_tuple
+from composer.utils import batch_get, batch_set, dist, ensure_tuple, is_model_deepspeed
 
 if TYPE_CHECKING:
     import deepspeed
@@ -120,7 +121,7 @@ class State(Serializable):
             ... )
             >>> trainer.fit()
             >>> trainer.state.current_metrics
-            {'train': {'Accuracy': tensor(...)}, 'eval': {'Accuracy': tensor(...)}}
+            {'train': {'Accuracy': tensor(...)}, 'eval': {'CrossEntropy': tensor(...), 'Accuracy': tensor(...)}}
 
             Or, when using an :class:`.Evaluator`:
 
@@ -604,16 +605,6 @@ class State(Serializable):
     def precision(self, precision: Union[str, Precision]):
         self._precision = Precision(precision)
 
-    @property
-    def is_model_deepspeed(self) -> bool:
-        """Whether :attr:`model` is an instance of a :class:`~deepspeed.DeepSpeedEngine`."""
-        try:
-            import deepspeed
-        except ImportError:
-            return False
-        else:
-            return isinstance(self.model, deepspeed.DeepSpeedEngine)
-
     @property
     def is_model_ddp(self):
         """Whether :attr:`model` is an instance of a :class:`.DistributedDataParallel`."""
@@ -622,6 +613,6 @@ class State(Serializable):
     @property
     def deepspeed_model(self) -> deepspeed.DeepSpeedEngine:
         """Cast :attr:`model` to :class:`~deepspeed.DeepSpeedEngine`."""
-        if self.is_model_deepspeed:
+        if is_model_deepspeed(self.model):
             return cast('deepspeed.DeepSpeedEngine', self.model)
         raise TypeError('state.model is not a DeepSpeed model')
