@@ -10,68 +10,25 @@ details about this dataset.
 import glob
 import os
 import random
-from dataclasses import dataclass
 
 import numpy as np
 import torch
 import torch.utils.data
 import torchvision
-import yahp as hp
 
-from composer.datasets.dataloader import DataLoaderHparams
-from composer.datasets.hparams import DatasetHparams
-from composer.utils import dist
 from composer.utils.import_helpers import MissingConditionalImportError
 
 PATCH_SIZE = [1, 192, 160]
 
-__all__ = ["BratsDatasetHparams"]
+__all__ = ['PytTrain', 'PytVal']
 
 
-def _my_collate(batch):
-    """Custom collate function to handle images with different depths."""
-    data = [item[0] for item in batch]
-    target = [item[1] for item in batch]
-
-    return [torch.Tensor(data), torch.Tensor(target)]
-
-
-@dataclass
-class BratsDatasetHparams(DatasetHparams):
-    """Defines an instance of the BraTS dataset for image segmentation.
-
-    Args:
-        oversampling (float): The oversampling ratio to use. Default: ``0.33``.
-    """
-
-    oversampling: float = hp.optional("oversampling", default=0.33)
-
-    def initialize_object(self, batch_size: int, dataloader_hparams: DataLoaderHparams):
-
-        oversampling = self.oversampling
-
-        if self.datadir is None:
-            raise ValueError("datadir must be specified.")
-        x_train, y_train, x_val, y_val = get_data_split(self.datadir)
-        dataset = PytTrain(x_train, y_train, oversampling) if self.is_train else PytVal(x_val, y_val)
-        collate_fn = None if self.is_train else _my_collate
-        sampler = dist.get_sampler(dataset, drop_last=self.drop_last, shuffle=self.shuffle)
-
-        return dataloader_hparams.initialize_object(
-            dataset=dataset,
-            batch_size=batch_size,
-            sampler=sampler,
-            drop_last=self.drop_last,
-            collate_fn=collate_fn,
-        )
-
-
-def coin_flip(prob):
+def _coin_flip(prob):
     return random.random() < prob
 
 
-def random_augmentation(probability, augmented, original):
-    condition = coin_flip(probability)
+def _random_augmentation(probability, augmented, original):
+    condition = _coin_flip(probability)
     neg_condition = condition ^ True
     return condition * augmented + neg_condition * original
 
@@ -79,7 +36,7 @@ def random_augmentation(probability, augmented, original):
 class Crop(object):
 
     def __call__(self, data, oversampling):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
 
         def randrange(max_range):
             return 0 if max_range == 0 else random.randrange(max_range)
@@ -142,11 +99,11 @@ class Crop(object):
 class Noise(object):
 
     def __call__(self, data, oversampling):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
         std = np.random.uniform(0.0, oversampling)
         noise = np.random.normal(0, scale=std, size=img.shape)
         img_noised = img + noise
-        img = random_augmentation(0.15, img_noised, img)
+        img = _random_augmentation(0.15, img_noised, img)
 
         return {'image': img, 'label': lbl}
 
@@ -154,11 +111,11 @@ class Noise(object):
 class Blur(object):
 
     def __call__(self, data):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
 
         transf = torchvision.transforms.GaussianBlur(kernel_size=3, sigma=(0.5, 1.5))
         img_blured = transf(torch.Tensor(img)).numpy()
-        img = random_augmentation(0.15, img_blured, img)
+        img = _random_augmentation(0.15, img_blured, img)
 
         return {'image': img, 'label': lbl}
 
@@ -166,8 +123,8 @@ class Blur(object):
 class Brightness(object):
 
     def __call__(self, data):
-        img, lbl = data["image"], data["label"]
-        brightness_scale = random_augmentation(0.15, np.random.uniform(0.7, 1.3), 1.0)
+        img, lbl = data['image'], data['label']
+        brightness_scale = _random_augmentation(0.15, np.random.uniform(0.7, 1.3), 1.0)
         img = img * brightness_scale
 
         return {'image': img, 'label': lbl}
@@ -176,9 +133,9 @@ class Brightness(object):
 class Contrast(object):
 
     def __call__(self, data):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
         min_, max_ = np.min(img), np.max(img)
-        scale = random_augmentation(0.15, np.random.uniform(0.65, 1.5), 1.0)
+        scale = _random_augmentation(0.15, np.random.uniform(0.65, 1.5), 1.0)
 
         img = torch.clamp(torch.Tensor(img * scale), min_, max_).numpy()
         return {'image': img, 'label': lbl}
@@ -187,7 +144,7 @@ class Contrast(object):
 class Flips(object):
 
     def __call__(self, data):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
         axes = [1, 2]
         prob = 1 / len(axes)
 
@@ -202,7 +159,7 @@ class Flips(object):
 class Transpose(object):
 
     def __call__(self, data):
-        img, lbl = data["image"], data["label"]
+        img, lbl = data['image'], data['label']
         img, lbl = img.transpose((1, 0, 2, 3)), lbl.transpose((1, 0, 2, 3))
 
         return {'image': img, 'label': lbl}
@@ -226,7 +183,7 @@ class PytTrain(torch.utils.data.Dataset):
         return len(self.images)
 
     def __getitem__(self, idx):
-        data = {"image": np.load(self.images[idx]), "label": np.load(self.labels[idx])}
+        data = {'image': np.load(self.images[idx]), 'label': np.load(self.labels[idx])}
         data = self.rand_crop(data, self.oversampling)
         data = self.flips(data)
         data = self.noise(data, self.oversampling)
@@ -235,7 +192,7 @@ class PytTrain(torch.utils.data.Dataset):
         data = self.contrast(data)
         data = self.transpose(data)
 
-        return data["image"], data["label"]
+        return data['image'], data['label']
 
 
 class PytVal(torch.utils.data.Dataset):
@@ -247,13 +204,13 @@ class PytVal(torch.utils.data.Dataset):
         return len(self.images)
 
     def __getitem__(self, idx):
-        data = {"image": np.load(self.images[idx]), "label": np.load(self.labels[idx])}
-        return data["image"], data["label"]
+        data = {'image': np.load(self.images[idx]), 'label': np.load(self.labels[idx])}
+        return data['image'], data['label']
 
 
 def load_data(path, files_pattern):
     data = sorted(glob.glob(os.path.join(path, files_pattern)))
-    assert len(data) > 0, f"Found no data at {path}"
+    assert len(data) > 0, f'Found no data at {path}'
     return data
 
 
@@ -265,13 +222,13 @@ def get_data_split(path: str):
     try:
         from sklearn.model_selection import KFold
     except ImportError as e:
-        raise MissingConditionalImportError(extra_deps_group="unet",
-                                            conda_channel="conda-forge",
-                                            conda_package="scikit-learn") from e
+        raise MissingConditionalImportError(extra_deps_group='unet',
+                                            conda_channel='conda-forge',
+                                            conda_package='scikit-learn') from e
     kfold = KFold(n_splits=5, shuffle=True, random_state=0)
-    imgs = load_data(path, "*_x.npy")
-    lbls = load_data(path, "*_y.npy")
-    assert len(imgs) == len(lbls), f"Found {len(imgs)} volumes but {len(lbls)} corresponding masks"
+    imgs = load_data(path, '*_x.npy')
+    lbls = load_data(path, '*_y.npy')
+    assert len(imgs) == len(lbls), f'Found {len(imgs)} volumes but {len(lbls)} corresponding masks'
     train_imgs, train_lbls, val_imgs, val_lbls = [], [], [], []
 
     train_idx, val_idx = list(kfold.split(imgs))[0]
