@@ -15,7 +15,6 @@
     # replace some layers with squeeze-excite
     cf.apply_squeeze_excite(model, latent_channels=64, min_channels=128)
 """
-from composer.algorithms.agc import apply_agc
 from composer.algorithms.alibi.alibi import apply_alibi
 from composer.algorithms.augmix import augmix_image
 from composer.algorithms.blurpool import apply_blurpool
@@ -25,7 +24,10 @@ from composer.algorithms.cutmix import cutmix_batch
 from composer.algorithms.cutout import cutout_batch
 from composer.algorithms.ema import compute_ema
 from composer.algorithms.factorize import apply_factorization
+from composer.algorithms.fused_layernorm import apply_fused_layernorm
+from composer.algorithms.gated_linear_units import apply_gated_linear_units
 from composer.algorithms.ghost_batchnorm.ghost_batchnorm import apply_ghost_batchnorm
+from composer.algorithms.gradient_clipping import apply_gradient_clipping
 from composer.algorithms.label_smoothing import smooth_labels
 from composer.algorithms.layer_freezing import freeze_layers
 from composer.algorithms.mixup import mixup_batch
@@ -38,25 +40,27 @@ from composer.algorithms.stochastic_depth import apply_stochastic_depth
 
 # All must be manually defined so sphinx automodule will work properly
 __all__ = [
-    "apply_agc",
-    "apply_alibi",
-    "augmix_image",
-    "apply_blurpool",
-    "apply_channels_last",
-    "colout_batch",
-    "compute_ema",
-    "cutmix_batch",
-    "cutout_batch",
-    "apply_factorization",
-    "apply_ghost_batchnorm",
-    "smooth_labels",
-    "freeze_layers",
-    "mixup_batch",
-    "resize_batch",
-    "randaugment_image",
-    "should_selective_backprop",
-    "select_using_loss",
-    "set_batch_sequence_length",
-    "apply_squeeze_excite",
-    "apply_stochastic_depth",
+    'apply_alibi',
+    'augmix_image',
+    'apply_blurpool',
+    'apply_channels_last',
+    'colout_batch',
+    'compute_ema',
+    'cutmix_batch',
+    'cutout_batch',
+    'apply_factorization',
+    'apply_fused_layernorm',
+    'apply_gated_linear_units',
+    'apply_ghost_batchnorm',
+    'apply_gradient_clipping',
+    'smooth_labels',
+    'freeze_layers',
+    'mixup_batch',
+    'resize_batch',
+    'randaugment_image',
+    'should_selective_backprop',
+    'select_using_loss',
+    'set_batch_sequence_length',
+    'apply_squeeze_excite',
+    'apply_stochastic_depth',
 ]
