@@ -8,14 +8,14 @@ classification training loop with :func:`.soft_cross_entropy` loss and accuracy
 """
 
 import logging
-from typing import Any, Optional, Tuple, Union
+from typing import Any, Callable, Optional, Tuple, Union
 
 import torch
 from torch import Tensor
 from torchmetrics import Metric, MetricCollection
 from torchmetrics.classification import Accuracy
 
-from composer.loss import loss_registry
+from composer.loss import soft_cross_entropy
 from composer.metrics import CrossEntropy
 from composer.models import ComposerModel
 
@@ -27,13 +27,16 @@ log = logging.getLogger(__name__)
 class ComposerClassifier(ComposerModel):
     """A convenience class that creates a :class:`.ComposerModel` for classification tasks from a vanilla PyTorch model.
     :class:`.ComposerClassifier` requires batches in the form: (``input``, ``target``) and includes a basic
-    classification training loop with :func:`.soft_cross_entropy` loss and accuracy logging.
+    classification training loop with a loss function `loss_fn` which takes in the model's outputs and the labels.
 
     Args:
         module (torch.nn.Module): A PyTorch neural network module.
-        loss_name (str, optional): Loss function to use. E.g. 'soft_cross_entropy' or
-            'binary_cross_entropy_with_logits'. Loss function must be in
-            :mod:`~composer.loss.loss`. Default: ``'soft_cross_entropy'``".
+        train_metrics (Metric | MetricCollection, optional): A torchmetric or collection of torchmetrics to be
+            computed on the training set throughout training.
+        val_metrics (Metric | MetricCollection, optional): A torchmetric or collection of torchmetrics to be
+            computed on the validation set throughout training.
+        loss_fn (Callable, optional): Loss function to use. This loss function should have at least two arguments:
+            1) the output of the model and 2) ``target`` i.e. labels from the dataset.
 
     Returns:
         ComposerClassifier: An instance of :class:`.ComposerClassifier`.
@@ -51,44 +54,42 @@ class ComposerClassifier(ComposerModel):
 
     num_classes: Optional[int] = None
 
-    def __init__(self, module: torch.nn.Module, loss_name: str = 'soft_cross_entropy') -> None:
+    def __init__(self,
+                 module: torch.nn.Module,
+                 train_metrics: Optional[Union[Metric, MetricCollection]] = None,
+                 val_metrics: Optional[Union[Metric, MetricCollection]] = None,
+                 loss_fn: Callable = soft_cross_entropy) -> None:
         super().__init__()
-        self.train_acc = Accuracy()
-        self.val_acc = Accuracy()
-        self.val_loss = CrossEntropy()
+
+        # Metrics for training
+        if train_metrics is None:
+            train_metrics = Accuracy()
+        self.train_metrics = train_metrics
+
+        # Metrics for validation
+        if val_metrics is None:
+            val_metrics = MetricCollection([CrossEntropy(), Accuracy()])
+        self.val_metrics = val_metrics
+
         self.module = module
-        if loss_name not in loss_registry.keys():
-            raise ValueError(f'Unrecognized loss function: {loss_name}. Please ensure the '
-                             'specified loss function is present in composer.loss.loss.py')
-        self._loss_fxn = loss_registry[loss_name]
+        self._loss_fn = loss_fn
 
         if hasattr(self.module, 'num_classes'):
             self.num_classes = getattr(self.module, 'num_classes')
 
-        if loss_name == 'binary_cross_entropy_with_logits':
-            log.warning('UserWarning: Using `binary_cross_entropy_loss_with_logits` '
-                        'without using `initializers.linear_log_constant_bias` can degrade '
-                        'performance. '
-                        'Please ensure you are using `initializers. '
-                        'linear_log_constant_bias`.')
-
-    def loss(self, outputs: Any, batch: Any, *args, **kwargs) -> Tensor:
+    def loss(self, outputs: Tensor, batch: Tuple[Any, Tensor], *args, **kwargs) -> Tensor:
         _, targets = batch
-        if not isinstance(outputs, Tensor):  # to pass typechecking
-            raise ValueError('Loss expects input as Tensor')
-        if not isinstance(targets, Tensor):
-            raise ValueError('Loss does not support multiple target Tensors')
-        return self._loss_fxn(outputs, targets, *args, **kwargs)
+        return self._loss_fn(outputs, targets, *args, **kwargs)
 
     def metrics(self, train: bool = False) -> Union[Metric, MetricCollection]:
-        return self.train_acc if train else MetricCollection([self.val_acc, self.val_loss])
+        return self.train_metrics if train else self.val_metrics
 
-    def forward(self, batch: Tuple[Tensor, Tensor]) -> Tensor:
+    def forward(self, batch: Tuple[Tensor, Any]) -> Tensor:
         inputs, _ = batch
         outputs = self.module(inputs)
         return outputs
 
-    def validate(self, batch: Any) -> Tuple[Any, Any]:
+    def validate(self, batch: Tuple[Tensor, Tensor]) -> Tuple[Tensor, Tensor]:
         _, targets = batch
         outputs = self.forward(batch)
         return outputs, targets
