@@ -4,7 +4,7 @@
 """A wrapper around `timm.create_model() <https://rwightman.github.io/pytorch-image-models/#load-a-pretrained-model>`_
 used to create :class:`.ComposerClassifier`."""
 
-from composer.models.timm.model import Timm as Timm
+from composer.models.timm.model import composer_timm as composer_timm
 from composer.models.timm.timm_hparams import TimmHparams as TimmHparams
 
-__all__ = ['Timm', 'TimmHparams']
+__all__ = ['composer_timm', 'TimmHparams']
