@@ -1,7 +1,7 @@
 # Copyright 2022 MosaicML Composer authors
 # SPDX-License-Identifier: Apache-2.0
 
-"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.ViTSmallPatch16`."""
+"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :func:`.vit_small_patch16`."""
 
 from dataclasses import dataclass
 
@@ -15,7 +15,7 @@ __all__ = ['ViTSmallPatch16Hparams']
 
 @dataclass
 class ViTSmallPatch16Hparams(ModelHparams):
-    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.ViTSmallPatch16`.
+    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.vit_small_batch16`.
 
     Args:
         num_classes (int, optional): number of classes for the model. Default: ``1000``.
@@ -41,9 +41,9 @@ class ViTSmallPatch16Hparams(ModelHparams):
         del vit_pytorch  # unused
 
     def initialize_object(self):
-        from composer.models import ViTSmallPatch16
-        return ViTSmallPatch16(num_classes=self.num_classes,
-                               image_size=self.image_size,
-                               channels=self.channels,
-                               dropout=self.dropout,
-                               embedding_dropout=self.embedding_dropout)
+        from composer.models import vit_small_patch16
+        return vit_small_patch16(num_classes=self.num_classes,
+                                 image_size=self.image_size,
+                                 channels=self.channels,
+                                 dropout=self.dropout,
+                                 embedding_dropout=self.embedding_dropout)
