@@ -9,8 +9,9 @@ from composer.utils.file_helpers import (create_symlink_file, ensure_folder_has_
                                          ensure_folder_is_empty, format_name_with_dist, format_name_with_dist_and_time,
                                          get_file, is_tar)
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
+from composer.utils.inference import export_for_inference, export_with_logger
 from composer.utils.iter_helpers import IteratorFileStream, ensure_tuple, map_collection
-from composer.utils.misc import is_notebook
+from composer.utils.misc import is_model_deepspeed, is_notebook
 from composer.utils.object_store import (LibcloudObjectStore, ObjectStore, ObjectStoreTransientError, S3ObjectStore,
                                          SFTPObjectStore)
 from composer.utils.retrying import retry
@@ -29,12 +30,15 @@ __all__ = [
     'SFTPObjectStore',
     'MissingConditionalImportError',
     'import_object',
+    'is_model_deepspeed',
     'is_notebook',
     'StringEnum',
     'load_checkpoint',
     'save_checkpoint',
     'ensure_folder_is_empty',
     'ensure_folder_has_no_conflicting_files',
+    'export_for_inference',
+    'export_with_logger',
     'format_name_with_dist',
     'format_name_with_dist_and_time',
     'is_tar',
